@@ -1440,7 +1440,8 @@ http_header(const char *header_data, const char *force_status,
 	strlcpy(logn, config.logaccess, sizeof(logn));
 
 	/* virtual hosts */
-	if (h->x_hos == 1 && strcmp(http_url, h->rq_fv_hos) != 0) {
+	if (h->x_hos == 1 && strcmp(http_url, h->rq_fv_hos) != 0 &&
+	    strcmp(http_urls, h->rq_fv_hos) != 0) {
 		/* search for virutal host in configuration */
 		if (fparse(h->rq_docrootv, h->rq_fv_hos, config.file,
 		    sizeof(h->rq_docrootv)) > 0) {
@@ -1578,10 +1579,10 @@ http_header(const char *header_data, const char *force_status,
 			/* create exact location uri */
 			if (c[sfd].x_ssl)
 				snprintf(h->rp_fv_loc, sizeof(h->rp_fv_loc),
-				    "https://%s%s/", http_urls, h->rq_uri);
+				    "https://%s%s/", h->rq_fv_hos, h->rq_uri);
 			else
 				snprintf(h->rp_fv_loc, sizeof(h->rp_fv_loc),
-				    "http://%s%s/", http_url, h->rq_uri);
+				    "http://%s%s/", h->rq_fv_hos, h->rq_uri);
 			/* set 301 headers content type */
 			strlcpy(h->rp_fv_cte, http_fv_cte,
 			    sizeof(h->rp_fv_cte));
