@@ -53,32 +53,64 @@ int
 sys_mime(char *dst, const int dsize, const char *mimes, const int msize,
     const char *type)
 {
-	int	i, j, k;
+	int	i, j, k, field, comment;
 	char	*x, l[2][1024];
-	
-	for (i = 0, j = 0, k = 0; i <= msize; i++) {
-		/* no control characters found, read */
-		if (mimes[i] != ' ' && mimes[i] != '\t' && mimes[i] != '\n') {
-			l[j][k] = mimes[i];
-			k++;
+
+	field = 1;
+	comment = 0;
+
+	for (i = 0, j = 0, k = 0; i < msize && k < sizeof(l[0]); i++) {
+		if (mimes[i] == '#')
+			comment = 1;
+		if (comment) {
+			if (mimes[i] == '\n')
+				comment = 0;
+			continue;
 		}
-		/* second field starts */
-		if (mimes[i] == ' ' || mimes[i] == '\t') {
+
+		switch (field) {
+		case 1:
+			if (mimes[i] == '\n') {
+				j = 0; k = 0; field = 1;
+				break;
+			}
+
+			if (mimes[i] != ' ' && mimes[i] != '\t') {
+				l[j][k] = mimes[i];
+				k++;
+			} else {
+				l[j][k] = '\0';
+				field = 2;
+			}
+			break;
+		case 2:
+			if (mimes[i] == '\n') {
+				j = 0; k = 0; field = 1;
+				break;
+			}
+
+			if (mimes[i] != ' ' && mimes[i] != '\t') {
+				j = 1; k = 0; field = 3;
+				l[j][k] = mimes[i];
+				k++;
+			}
+			break;
+		case 3:
+			if (mimes[i] != '\n') {
+				l[j][k] = mimes[i];
+				k++;
+				break;
+			}
+
 			l[j][k] = '\0';
-			j = 1;
-			k = 0;
-		}
-		/* end of line */
-		if (mimes[i] == '\n') {
-			l[j][k] = '\0';
-			for (x = strtok(l[1], ","); x; x = strtok(NULL, ",")) {
+			for (x = strtok(l[1], " "); x; x = strtok(NULL, " ")) {
 				if (strcasecmp(x, type) == 0) {
 					strlcpy(dst, l[0], dsize);
 					return (1);
 				}
 			}
-			j = 0;
-			k = 0;
+			j = 0; k = 0; field = 1;
+			break;
 		}
 	}
 
